require "./web/examples.rb"
require "./lazylib.rb"
require "./run.rb"
require "stringio"

def output(str)
  $output << str
end

pass = true

tests = ExamplesAndTests
tests.each{|name, prog, input, expected|
  begin
    $output = ""
    input_stream = Array === input ? input : StringIO.new(input)
    run_and_do_io(prog,input_stream,false,false)

    if $output != expected
      STDERR.puts "FAIL: #{name}"
      STDERR.puts prog
      STDERR.puts "expected:"
      STDERR.print expected
      STDERR.puts "EOF"
      STDERR.puts "found:"
      STDERR.print $output
      STDERR.puts "EOF"
      pass = false
    end
  rescue => e
    pass = false
    STDERR.puts "error in "+name
    raise e
  end
}

puts "PASS #{tests.size} examples" if pass
